from __future__ import absolute_import, division, print_function, unicode_literals

WINE_CLASSIFICATIONS = {'1er Cru', '1er Cru Classé', '1er Grand Cru', '2ème Cru Classé', '2ème Vin',
                        '4ème Cru Classé', 'Cru Classé', 'Grand Cru', 'Non Classé'}
WINE_PACKING_TYPE = {'OCB06', 'OCB12', 'OWC06', 'OWC01', 'OWC02', 'OWC03', 'OWC06', 'OWC12'}
